nessie\_client.auth package
===========================

Submodules
----------

nessie\_client.auth.basic module
--------------------------------

.. automodule:: pynessie.auth.basic
    :members:
    :undoc-members:
    :show-inheritance:

nessie\_client.auth.config module
---------------------------------

.. automodule:: pynessie.auth.config
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pynessie.auth
    :members:
    :undoc-members:
    :show-inheritance:
